@@ -2,10 +2,10 @@
 
 """
 
-import os,  inspect
+import os, inspect
 currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
 parentdir = os.path.dirname(os.path.dirname(currentdir))
-os.sys.path.insert(0,parentdir)
+os.sys.path.insert(0, parentdir)
 
 import collections
 import copy
@@ -24,9 +24,8 @@ OVERHEAT_SHUTDOWN_TORQUE = 2.45
 OVERHEAT_SHUTDOWN_TIME = 1.0
 LEG_POSITION = ["front_left", "back_left", "front_right", "back_right"]
 MOTOR_NAMES = [
-    "motor_front_leftL_joint", "motor_front_leftR_joint",
-    "motor_back_leftL_joint", "motor_back_leftR_joint",
-    "motor_front_rightL_joint", "motor_front_rightR_joint",
+    "motor_front_leftL_joint", "motor_front_leftR_joint", "motor_back_leftL_joint",
+    "motor_back_leftR_joint", "motor_front_rightL_joint", "motor_front_rightR_joint",
     "motor_back_rightL_joint", "motor_back_rightR_joint"
 ]
 _CHASSIS_NAME_PATTERN = re.compile(r"chassis\D*center")
@@ -141,10 +140,9 @@ class Minitaur(object):
     if self._accurate_motor_model_enabled:
       self._kp = motor_kp
       self._kd = motor_kd
-      self._motor_model = motor.MotorModel(
-          torque_control_enabled=self._torque_control_enabled,
-          kp=self._kp,
-          kd=self._kd)
+      self._motor_model = motor.MotorModel(torque_control_enabled=self._torque_control_enabled,
+                                           kp=self._kp,
+                                           kd=self._kd)
     elif self._pd_control_enabled:
       self._kp = 8
       self._kd = 0.3
@@ -188,17 +186,14 @@ class Minitaur(object):
     self._link_urdf = []
     num_bodies = self._pybullet_client.getNumJoints(self.quadruped)
     for body_id in range(-1, num_bodies):  # -1 is for the base link.
-      inertia = self._pybullet_client.getDynamicsInfo(self.quadruped,
-                                                      body_id)[2]
+      inertia = self._pybullet_client.getDynamicsInfo(self.quadruped, body_id)[2]
       self._link_urdf.append(inertia)
     # We need to use id+1 to index self._link_urdf because it has the base
     # (index = -1) at the first element.
     self._base_inertia_urdf = [
         self._link_urdf[chassis_id + 1] for chassis_id in self._chassis_link_ids
     ]
-    self._leg_inertia_urdf = [
-        self._link_urdf[leg_id + 1] for leg_id in self._leg_link_ids
-    ]
+    self._leg_inertia_urdf = [self._link_urdf[leg_id + 1] for leg_id in self._leg_link_ids]
     self._leg_inertia_urdf.extend(
         [self._link_urdf[motor_id + 1] for motor_id in self._motor_link_ids])
 
@@ -239,13 +234,10 @@ class Minitaur(object):
     num_joints = self._pybullet_client.getNumJoints(self.quadruped)
     for i in range(num_joints):
       joint_info = self._pybullet_client.getJointInfo(self.quadruped, i)
-      self._pybullet_client.changeDynamics(
-          joint_info[0], -1, linearDamping=0, angularDamping=0)
+      self._pybullet_client.changeDynamics(joint_info[0], -1, linearDamping=0, angularDamping=0)
 
   def _BuildMotorIdList(self):
-    self._motor_id_list = [
-        self._joint_name_to_id[motor_name] for motor_name in MOTOR_NAMES
-    ]
+    self._motor_id_list = [self._joint_name_to_id[motor_name] for motor_name in MOTOR_NAMES]
 
   def IsObservationValid(self):
     """Whether the observation is valid for the current time step.
@@ -284,10 +276,10 @@ class Minitaur(object):
             useFixedBase=self._on_rack,
             flags=self._pybullet_client.URDF_USE_SELF_COLLISION)
       else:
-        self.quadruped = self._pybullet_client.loadURDF(
-            "%s/quadruped/minitaur.urdf" % self._urdf_root,
-            init_position,
-            useFixedBase=self._on_rack)
+        self.quadruped = self._pybullet_client.loadURDF("%s/quadruped/minitaur.urdf" %
+                                                        self._urdf_root,
+                                                        init_position,
+                                                        useFixedBase=self._on_rack)
       self._BuildJointNameToIdDict()
       self._BuildUrdfIds()
       if self._remove_default_joint_damping:
@@ -297,10 +289,9 @@ class Minitaur(object):
       self._RecordInertiaInfoFromURDF()
       self.ResetPose(add_constraint=True)
     else:
-      self._pybullet_client.resetBasePositionAndOrientation(
-          self.quadruped, init_position, INIT_ORIENTATION)
-      self._pybullet_client.resetBaseVelocity(self.quadruped, [0, 0, 0],
-                                              [0, 0, 0])
+      self._pybullet_client.resetBasePositionAndOrientation(self.quadruped, init_position,
+                                                            INIT_ORIENTATION)
+      self._pybullet_client.resetBaseVelocity(self.quadruped, [0, 0, 0], [0, 0, 0])
       self.ResetPose(add_constraint=False)
     self._overheat_counter = np.zeros(self.num_motors)
     self._motor_enabled_list = [True] * self.num_motors
@@ -325,25 +316,22 @@ class Minitaur(object):
     self.ReceiveObservation()
 
   def _SetMotorTorqueById(self, motor_id, torque):
-    self._pybullet_client.setJointMotorControl2(
-        bodyIndex=self.quadruped,
-        jointIndex=motor_id,
-        controlMode=self._pybullet_client.TORQUE_CONTROL,
-        force=torque)
+    self._pybullet_client.setJointMotorControl2(bodyIndex=self.quadruped,
+                                                jointIndex=motor_id,
+                                                controlMode=self._pybullet_client.TORQUE_CONTROL,
+                                                force=torque)
 
   def _SetDesiredMotorAngleById(self, motor_id, desired_angle):
-    self._pybullet_client.setJointMotorControl2(
-        bodyIndex=self.quadruped,
-        jointIndex=motor_id,
-        controlMode=self._pybullet_client.POSITION_CONTROL,
-        targetPosition=desired_angle,
-        positionGain=self._kp,
-        velocityGain=self._kd,
-        force=self._max_force)
+    self._pybullet_client.setJointMotorControl2(bodyIndex=self.quadruped,
+                                                jointIndex=motor_id,
+                                                controlMode=self._pybullet_client.POSITION_CONTROL,
+                                                targetPosition=desired_angle,
+                                                positionGain=self._kp,
+                                                velocityGain=self._kd,
+                                                force=self._max_force)
 
   def _SetDesiredMotorAngleByName(self, motor_name, desired_angle):
-    self._SetDesiredMotorAngleById(self._joint_name_to_id[motor_name],
-                                   desired_angle)
+    self._SetDesiredMotorAngleById(self._joint_name_to_id[motor_name], desired_angle)
 
   def ResetPose(self, add_constraint):
     """Reset the pose of the minitaur.
@@ -367,59 +355,53 @@ class Minitaur(object):
     knee_angle = -2.1834
 
     leg_position = LEG_POSITION[leg_id]
-    self._pybullet_client.resetJointState(
-        self.quadruped,
-        self._joint_name_to_id["motor_" + leg_position + "L_joint"],
-        self._motor_direction[2 * leg_id] * half_pi,
-        targetVelocity=0)
-    self._pybullet_client.resetJointState(
-        self.quadruped,
-        self._joint_name_to_id["knee_" + leg_position + "L_link"],
-        self._motor_direction[2 * leg_id] * knee_angle,
-        targetVelocity=0)
-    self._pybullet_client.resetJointState(
-        self.quadruped,
-        self._joint_name_to_id["motor_" + leg_position + "R_joint"],
-        self._motor_direction[2 * leg_id + 1] * half_pi,
-        targetVelocity=0)
-    self._pybullet_client.resetJointState(
-        self.quadruped,
-        self._joint_name_to_id["knee_" + leg_position + "R_link"],
-        self._motor_direction[2 * leg_id + 1] * knee_angle,
-        targetVelocity=0)
+    self._pybullet_client.resetJointState(self.quadruped,
+                                          self._joint_name_to_id["motor_" + leg_position +
+                                                                 "L_joint"],
+                                          self._motor_direction[2 * leg_id] * half_pi,
+                                          targetVelocity=0)
+    self._pybullet_client.resetJointState(self.quadruped,
+                                          self._joint_name_to_id["knee_" + leg_position +
+                                                                 "L_link"],
+                                          self._motor_direction[2 * leg_id] * knee_angle,
+                                          targetVelocity=0)
+    self._pybullet_client.resetJointState(self.quadruped,
+                                          self._joint_name_to_id["motor_" + leg_position +
+                                                                 "R_joint"],
+                                          self._motor_direction[2 * leg_id + 1] * half_pi,
+                                          targetVelocity=0)
+    self._pybullet_client.resetJointState(self.quadruped,
+                                          self._joint_name_to_id["knee_" + leg_position +
+                                                                 "R_link"],
+                                          self._motor_direction[2 * leg_id + 1] * knee_angle,
+                                          targetVelocity=0)
     if add_constraint:
       self._pybullet_client.createConstraint(
-          self.quadruped,
-          self._joint_name_to_id["knee_" + leg_position + "R_link"],
-          self.quadruped,
-          self._joint_name_to_id["knee_" + leg_position + "L_link"],
-          self._pybullet_client.JOINT_POINT2POINT, [0, 0, 0],
-          KNEE_CONSTRAINT_POINT_RIGHT, KNEE_CONSTRAINT_POINT_LEFT)
+          self.quadruped, self._joint_name_to_id["knee_" + leg_position + "R_link"],
+          self.quadruped, self._joint_name_to_id["knee_" + leg_position + "L_link"],
+          self._pybullet_client.JOINT_POINT2POINT, [0, 0, 0], KNEE_CONSTRAINT_POINT_RIGHT,
+          KNEE_CONSTRAINT_POINT_LEFT)
 
     if self._accurate_motor_model_enabled or self._pd_control_enabled:
       # Disable the default motor in pybullet.
       self._pybullet_client.setJointMotorControl2(
           bodyIndex=self.quadruped,
-          jointIndex=(
-              self._joint_name_to_id["motor_" + leg_position + "L_joint"]),
+          jointIndex=(self._joint_name_to_id["motor_" + leg_position + "L_joint"]),
           controlMode=self._pybullet_client.VELOCITY_CONTROL,
           targetVelocity=0,
           force=knee_friction_force)
       self._pybullet_client.setJointMotorControl2(
           bodyIndex=self.quadruped,
-          jointIndex=(
-              self._joint_name_to_id["motor_" + leg_position + "R_joint"]),
+          jointIndex=(self._joint_name_to_id["motor_" + leg_position + "R_joint"]),
           controlMode=self._pybullet_client.VELOCITY_CONTROL,
           targetVelocity=0,
           force=knee_friction_force)
 
     else:
-      self._SetDesiredMotorAngleByName(
-          "motor_" + leg_position + "L_joint",
-          self._motor_direction[2 * leg_id] * half_pi)
-      self._SetDesiredMotorAngleByName(
-          "motor_" + leg_position + "R_joint",
-          self._motor_direction[2 * leg_id + 1] * half_pi)
+      self._SetDesiredMotorAngleByName("motor_" + leg_position + "L_joint",
+                                       self._motor_direction[2 * leg_id] * half_pi)
+      self._SetDesiredMotorAngleByName("motor_" + leg_position + "R_joint",
+                                       self._motor_direction[2 * leg_id + 1] * half_pi)
 
     self._pybullet_client.setJointMotorControl2(
         bodyIndex=self.quadruped,
@@ -440,8 +422,7 @@ class Minitaur(object):
     Returns:
       The position of minitaur's base.
     """
-    position, _ = (
-        self._pybullet_client.getBasePositionAndOrientation(self.quadruped))
+    position, _ = (self._pybullet_client.getBasePositionAndOrientation(self.quadruped))
     return position
 
   def GetTrueBaseRollPitchYaw(self):
@@ -464,10 +445,9 @@ class Minitaur(object):
     """
     delayed_orientation = np.array(
         self._control_observation[3 * self.num_motors:3 * self.num_motors + 4])
-    delayed_roll_pitch_yaw = self._pybullet_client.getEulerFromQuaternion(
-        delayed_orientation)
-    roll_pitch_yaw = self._AddSensorNoise(
-        np.array(delayed_roll_pitch_yaw), self._observation_noise_stdev[3])
+    delayed_roll_pitch_yaw = self._pybullet_client.getEulerFromQuaternion(delayed_orientation)
+    roll_pitch_yaw = self._AddSensorNoise(np.array(delayed_roll_pitch_yaw),
+                                          self._observation_noise_stdev[3])
     return roll_pitch_yaw
 
   def GetTrueMotorAngles(self):
@@ -492,9 +472,8 @@ class Minitaur(object):
     Returns:
       Motor angles polluted by noise and latency, mapped to [-pi, pi].
     """
-    motor_angles = self._AddSensorNoise(
-        np.array(self._control_observation[0:self.num_motors]),
-        self._observation_noise_stdev[0])
+    motor_angles = self._AddSensorNoise(np.array(self._control_observation[0:self.num_motors]),
+                                        self._observation_noise_stdev[0])
     return MapToMinusPiToPi(motor_angles)
 
   def GetTrueMotorVelocities(self):
@@ -518,8 +497,7 @@ class Minitaur(object):
       Velocities of all eight motors polluted by noise and latency.
     """
     return self._AddSensorNoise(
-        np.array(
-            self._control_observation[self.num_motors:2 * self.num_motors]),
+        np.array(self._control_observation[self.num_motors:2 * self.num_motors]),
         self._observation_noise_stdev[1])
 
   def GetTrueMotorTorques(self):
@@ -546,8 +524,7 @@ class Minitaur(object):
       Motor torques of all eight motors polluted by noise and latency.
     """
     return self._AddSensorNoise(
-        np.array(
-            self._control_observation[2 * self.num_motors:3 * self.num_motors]),
+        np.array(self._control_observation[2 * self.num_motors:3 * self.num_motors]),
         self._observation_noise_stdev[2])
 
   def GetTrueBaseOrientation(self):
@@ -556,8 +533,7 @@ class Minitaur(object):
     Returns:
       The orientation of minitaur's base.
     """
-    _, orientation = (
-        self._pybullet_client.getBasePositionAndOrientation(self.quadruped))
+    _, orientation = (self._pybullet_client.getBasePositionAndOrientation(self.quadruped))
     return orientation
 
   def GetBaseOrientation(self):
@@ -567,8 +543,7 @@ class Minitaur(object):
     Returns:
       The orientation of minitaur's base polluted by noise and latency.
     """
-    return self._pybullet_client.getQuaternionFromEuler(
-        self.GetBaseRollPitchYaw())
+    return self._pybullet_client.getQuaternionFromEuler(self.GetBaseRollPitchYaw())
 
   def GetTrueBaseRollPitchYawRate(self):
     """Get the rate of orientation change of the minitaur's base in euler angle.
@@ -588,8 +563,7 @@ class Minitaur(object):
       and latency.
     """
     return self._AddSensorNoise(
-        np.array(self._control_observation[3 * self.num_motors + 4:
-                                           3 * self.num_motors + 7]),
+        np.array(self._control_observation[3 * self.num_motors + 4:3 * self.num_motors + 7]),
         self._observation_noise_stdev[4])
 
   def GetActionDimension(self):
@@ -618,12 +592,9 @@ class Minitaur(object):
     """
     if self._motor_velocity_limit < np.inf:
       current_motor_angle = self.GetTrueMotorAngles()
-      motor_commands_max = (
-          current_motor_angle + self.time_step * self._motor_velocity_limit)
-      motor_commands_min = (
-          current_motor_angle - self.time_step * self._motor_velocity_limit)
-      motor_commands = np.clip(motor_commands, motor_commands_min,
-                               motor_commands_max)
+      motor_commands_max = (current_motor_angle + self.time_step * self._motor_velocity_limit)
+      motor_commands_min = (current_motor_angle - self.time_step * self._motor_velocity_limit)
+      motor_commands = np.clip(motor_commands, motor_commands_min, motor_commands_max)
     # Set the kp and kd for all the motors if not provided as an argument.
     if motor_kps is None:
       motor_kps = np.full(8, self._kp)
@@ -642,8 +613,7 @@ class Minitaur(object):
               self._overheat_counter[i] += 1
             else:
               self._overheat_counter[i] = 0
-            if (self._overheat_counter[i] >
-                OVERHEAT_SHUTDOWN_TIME / self.time_step):
+            if (self._overheat_counter[i] > OVERHEAT_SHUTDOWN_TIME / self.time_step):
               self._motor_enabled_list[i] = False
 
         # The torque is already in the observation space because we use
@@ -651,19 +621,17 @@ class Minitaur(object):
         self._observed_motor_torques = observed_torque
 
         # Transform into the motor space when applying the torque.
-        self._applied_motor_torque = np.multiply(actual_torque,
-                                                 self._motor_direction)
+        self._applied_motor_torque = np.multiply(actual_torque, self._motor_direction)
 
-        for motor_id, motor_torque, motor_enabled in zip(
-            self._motor_id_list, self._applied_motor_torque,
-            self._motor_enabled_list):
+        for motor_id, motor_torque, motor_enabled in zip(self._motor_id_list,
+                                                         self._applied_motor_torque,
+                                                         self._motor_enabled_list):
           if motor_enabled:
             self._SetMotorTorqueById(motor_id, motor_torque)
           else:
             self._SetMotorTorqueById(motor_id, 0)
       else:
-        torque_commands = -1 * motor_kps * (
-            q - motor_commands) - motor_kds * qdot
+        torque_commands = -1 * motor_kps * (q - motor_commands) - motor_kds * qdot
 
         # The torque is already in the observation space because we use
         # GetMotorAngles and GetMotorVelocities.
@@ -673,14 +641,12 @@ class Minitaur(object):
         self._applied_motor_torques = np.multiply(self._observed_motor_torques,
                                                   self._motor_direction)
 
-        for motor_id, motor_torque in zip(self._motor_id_list,
-                                          self._applied_motor_torques):
+        for motor_id, motor_torque in zip(self._motor_id_list, self._applied_motor_torques):
           self._SetMotorTorqueById(motor_id, motor_torque)
     else:
-      motor_commands_with_direction = np.multiply(motor_commands,
-                                                  self._motor_direction)
-      for motor_id, motor_command_with_direction in zip(
-          self._motor_id_list, motor_commands_with_direction):
+      motor_commands_with_direction = np.multiply(motor_commands, self._motor_direction)
+      for motor_id, motor_command_with_direction in zip(self._motor_id_list,
+                                                        motor_commands_with_direction):
         self._SetDesiredMotorAngleById(motor_id, motor_command_with_direction)
 
   def ConvertFromLegModel(self, actions):
@@ -698,13 +664,13 @@ class Minitaur(object):
     quater_pi = math.pi / 4
     for i in range(self.num_motors):
       action_idx = int(i // 2)
-      forward_backward_component = (-scale_for_singularity * quater_pi * (
-          actions[action_idx + half_num_motors] + offset_for_singularity))
+      forward_backward_component = (
+          -scale_for_singularity * quater_pi *
+          (actions[action_idx + half_num_motors] + offset_for_singularity))
       extension_component = (-1)**i * quater_pi * actions[action_idx]
       if i >= half_num_motors:
         extension_component = -extension_component
-      motor_angle[i] = (
-          math.pi + forward_backward_component + extension_component)
+      motor_angle[i] = (math.pi + forward_backward_component + extension_component)
     return motor_angle
 
   def GetBaseMassesFromURDF(self):
@@ -734,12 +700,10 @@ class Minitaur(object):
         the length of self._chassis_link_ids.
     """
     if len(base_mass) != len(self._chassis_link_ids):
-      raise ValueError(
-          "The length of base_mass {} and self._chassis_link_ids {} are not "
-          "the same.".format(len(base_mass), len(self._chassis_link_ids)))
+      raise ValueError("The length of base_mass {} and self._chassis_link_ids {} are not "
+                       "the same.".format(len(base_mass), len(self._chassis_link_ids)))
     for chassis_id, chassis_mass in zip(self._chassis_link_ids, base_mass):
-      self._pybullet_client.changeDynamics(
-          self.quadruped, chassis_id, mass=chassis_mass)
+      self._pybullet_client.changeDynamics(self.quadruped, chassis_id, mass=chassis_mass)
 
   def SetLegMasses(self, leg_masses):
     """Set the mass of the legs.
@@ -759,12 +723,10 @@ class Minitaur(object):
       raise ValueError("The number of values passed to SetLegMasses are "
                        "different than number of leg links and motors.")
     for leg_id, leg_mass in zip(self._leg_link_ids, leg_masses):
-      self._pybullet_client.changeDynamics(
-          self.quadruped, leg_id, mass=leg_mass)
+      self._pybullet_client.changeDynamics(self.quadruped, leg_id, mass=leg_mass)
     motor_masses = leg_masses[len(self._leg_link_ids):]
     for link_id, motor_mass in zip(self._motor_link_ids, motor_masses):
-      self._pybullet_client.changeDynamics(
-          self.quadruped, link_id, mass=motor_mass)
+      self._pybullet_client.changeDynamics(self.quadruped, link_id, mass=motor_mass)
 
   def SetBaseInertias(self, base_inertias):
     """Set the inertias of minitaur's base.
@@ -779,17 +741,15 @@ class Minitaur(object):
         negative values.
     """
     if len(base_inertias) != len(self._chassis_link_ids):
-      raise ValueError(
-          "The length of base_inertias {} and self._chassis_link_ids {} are "
-          "not the same.".format(
-              len(base_inertias), len(self._chassis_link_ids)))
-    for chassis_id, chassis_inertia in zip(self._chassis_link_ids,
-                                           base_inertias):
+      raise ValueError("The length of base_inertias {} and self._chassis_link_ids {} are "
+                       "not the same.".format(len(base_inertias), len(self._chassis_link_ids)))
+    for chassis_id, chassis_inertia in zip(self._chassis_link_ids, base_inertias):
       for inertia_value in chassis_inertia:
         if (np.asarray(inertia_value) < 0).any():
           raise ValueError("Values in inertia matrix should be non-negative.")
-      self._pybullet_client.changeDynamics(
-          self.quadruped, chassis_id, localInertiaDiagonal=chassis_inertia)
+      self._pybullet_client.changeDynamics(self.quadruped,
+                                           chassis_id,
+                                           localInertiaDiagonal=chassis_inertia)
 
   def SetLegInertias(self, leg_inertias):
     """Set the inertias of the legs.
@@ -813,16 +773,18 @@ class Minitaur(object):
       for inertia_value in leg_inertias:
         if (np.asarray(inertia_value) < 0).any():
           raise ValueError("Values in inertia matrix should be non-negative.")
-      self._pybullet_client.changeDynamics(
-          self.quadruped, leg_id, localInertiaDiagonal=leg_inertia)
+      self._pybullet_client.changeDynamics(self.quadruped,
+                                           leg_id,
+                                           localInertiaDiagonal=leg_inertia)
 
     motor_inertias = leg_inertias[len(self._leg_link_ids):]
     for link_id, motor_inertia in zip(self._motor_link_ids, motor_inertias):
       for inertia_value in motor_inertias:
         if (np.asarray(inertia_value) < 0).any():
           raise ValueError("Values in inertia matrix should be non-negative.")
-      self._pybullet_client.changeDynamics(
-          self.quadruped, link_id, localInertiaDiagonal=motor_inertia)
+      self._pybullet_client.changeDynamics(self.quadruped,
+                                           link_id,
+                                           localInertiaDiagonal=motor_inertia)
 
   def SetFootFriction(self, foot_friction):
     """Set the lateral friction of the feet.
@@ -832,8 +794,7 @@ class Minitaur(object):
         shared by all four feet.
     """
     for link_id in self._foot_link_ids:
-      self._pybullet_client.changeDynamics(
-          self.quadruped, link_id, lateralFriction=foot_friction)
+      self._pybullet_client.changeDynamics(self.quadruped, link_id, lateralFriction=foot_friction)
 
   # TODO(b/73748980): Add more API's to set other contact parameters.
   def SetFootRestitution(self, foot_restitution):
@@ -844,8 +805,7 @@ class Minitaur(object):
         This value is shared by all four feet.
     """
     for link_id in self._foot_link_ids:
-      self._pybullet_client.changeDynamics(
-          self.quadruped, link_id, restitution=foot_restitution)
+      self._pybullet_client.changeDynamics(self.quadruped, link_id, restitution=foot_restitution)
 
   def SetJointFriction(self, joint_frictions):
     for knee_joint_id, friction in zip(self._foot_link_ids, joint_frictions):
@@ -901,9 +861,8 @@ class Minitaur(object):
         return self._observation_history[-1]
       remaining_latency = latency - n_steps_ago * self.time_step
       blend_alpha = remaining_latency / self.time_step
-      observation = (
-          (1.0 - blend_alpha) * np.array(self._observation_history[n_steps_ago])
-          + blend_alpha * np.array(self._observation_history[n_steps_ago + 1]))
+      observation = ((1.0 - blend_alpha) * np.array(self._observation_history[n_steps_ago]) +
+                     blend_alpha * np.array(self._observation_history[n_steps_ago + 1]))
     return observation
 
   def _GetPDObservation(self):
@@ -913,15 +872,13 @@ class Minitaur(object):
     return (np.array(q), np.array(qdot))
 
   def _GetControlObservation(self):
-    control_delayed_observation = self._GetDelayedObservation(
-        self._control_latency)
+    control_delayed_observation = self._GetDelayedObservation(self._control_latency)
     return control_delayed_observation
 
   def _AddSensorNoise(self, sensor_values, noise_stdev):
     if noise_stdev <= 0:
       return sensor_values
-    observation = sensor_values + np.random.normal(
-        scale=noise_stdev, size=sensor_values.shape)
+    observation = sensor_values + np.random.normal(scale=noise_stdev, size=sensor_values.shape)
     return observation
 
   def SetControlLatency(self, latency):
